### **Description**

#### tsBNgen is a Python package to generate time series data based on an arbitrary Bayesian Network Structures. 
---
### **Citation**

 #### For the correct citation please visit https://github.com/manitadayon/tsBNgen
----
### **Features**

 - It handles discrete nodes, continous nodes and hybrid (Mixture of discrete and continuous) network.

 - It uses multinomila distribution for the discrete nodes and Gaussian distribution for the continuous nodes.

 - It handles arbitrary Bayesian network structure.

 - It supports arbitrary loopback values.

 - The code can be modified easily to handle arbitrary static and temporal structures.
---

### **Instruction**

 To run this code either clone this repo or use the package distribution in PyPI using the following commands:

```python
pip install tsBNgen
```

 Then Run through the set of examples in 
 
 > **Time_Series_Generation_Examples.ipynb**

For more information on how to use the package please visit the following:

1. Original paper 
2. Documentation in PDF available in the github repository.

### **License**

This software is released under the MIT liecense.














